# Changelog

## [0.9.3] - 2020-04-29

Add additional debug logging

## [0.9.2] - 2020-04-16

Add an option to specify the full path to the state file

## [0.9.1] - 2020-04-11

Always use the heat and cool temperature
when we get a heat, a cool, and a target temperature

Fixes the jumping band in homekit

Fix emergency heat

## [0.9.0] - 2020-04-11

Add support for XL824

Supported XL950, XL1050, XL824
Not supported XL624

## [0.8.2] - 2020-04-10

* Fix detection of emergency heat
* Check device type to exclude non-thermostats

## [0.8.1] - 2020-04-10

* Resolve unexpected error handling HTTP 304 status
